## Checklist before merging 
- [ ] Documentation updated
- [ ] Config.json changes reflected in source/get_data.validate_config
- [ ] Version number updated in pyproject.toml
- [ ] Version number updated in commands/info.get_dodonacli_version()
- [ ] Changelog updated in commands/info.changelog() (only empty changelog after merge into master)
- [ ] Completion script updated